#include "CalamariWindow.h"

#include "DiffWidget.h"
#include <QAction>
#include <QCheckBox>
#include <QComboBox>
#include <QLayout>
#include <QToolBar>
#include <math.h>

CalamariWindow::CalamariWindow(QWidget *parent, Qt::WFlags flags, char* file1, char* file2, char* file3)
    : QMainWindow(parent, flags)
{
	diffWidget = new DiffWidget( file1, file2 );
	setCentralWidget( diffWidget );

	initDiffToolbar();

	zoomFactor = 0;
	diffWidget->setScale( 0 );
}

CalamariWindow::~CalamariWindow()
{

}

void CalamariWindow::setAutoSize( bool a )
{
	if ( a )
	{
		diffWidget->setScale( 0 );
	}
	else
	{
		diffWidget->setScale( pow( 2.0, zoomFactor ) );
	}
}

void CalamariWindow::setZoom( int index )
{
	zoomFactor = zoomList->itemData( index ).toInt();
	double scale = pow( 2.0, zoomFactor );
	diffWidget->setScale( scale );
}

void CalamariWindow::initDiffToolbar()
{
	QToolBar* tbar = addToolBar( "CALAMARI diff toolbar" );
	zoomList = new QComboBox;
	QAction* za = tbar->addWidget( zoomList );
	int d;
	int off = 3;
	zoomList->setInsertPolicy( QComboBox::InsertAtBottom );
	for ( int z = -3 ; z <= 3 ; z++ )
	{
		if ( z < 0 )
		{
			d = pow( 2, -z );
			zoomList->insertItem( z + off, "1/" + QString::number( d ) + " x", z );
		}
		else
		{
			d = pow( 2, z );
			zoomList->insertItem( z + off, QString::number( d ) + " x", z );
		}
	}
	zoomList->setCurrentIndex( 0 + off );
	connect( zoomList, SIGNAL(activated(int)), this, SLOT(setZoom(int)) );
	QCheckBox* asize = new QCheckBox( "Fit to window" );
	tbar->addWidget( asize );
	connect( asize, SIGNAL( toggled(bool) ), this, SLOT( setAutoSize(bool) ) );
	connect( asize, SIGNAL( toggled(bool) ), zoomList, SLOT( setDisabled(bool) ) );
	asize->setChecked( true );
}
